@@ -173,7 +173,6 @@ class CreateDPDShipping(Wizard):
         return {
             'printerLanguage': 'PDF',
             'paperFormat': 'A6',
-            'startPosition': 'UPPER_LEFT',
             }
 
     def shipping_party(self, party, address):
@@ -208,7 +207,7 @@ class CreateDPDShipping(Wizard):
 
         parcel = {
             'customerReferenceNumber1': package.code,
-            'weight': int(package.weight * 10) * 10
+            'weight': int(package.total_weight * 10) * 10
             }
 
         length = UoM.compute_qty(
